# remirepo spec file for php-pecl-rpminfo
#
# SPDX-FileCopyrightText:  Copyright 2024 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#

%bcond_without      tests

%{?scl:%scl_package php-pecl-rpminfo}

%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name   rpminfo
%global ini_name    40-%{pecl_name}.ini
%global sources     %{pecl_name}-%{version}
%global _configure  ../%{sources}/configure

Summary:        RPM information
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        1.2.0
Release:        1%{?dist}%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}
License:        PHP-3.01
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{sources}.tgz

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  pkgconfig(rpm) >= 4.13
BuildRequires:  %{?scl_prefix}php-devel >= 8.0
BuildRequires:  %{?scl_prefix}php-pear

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}
Provides:       %{?scl_prefix}php-pie(remi/%{pecl_name})     = %{version}


%description
Retrieve RPM information using librpm, from local
RPM file or from installed packages database.

Documentation: https://www.php.net/rpminfo

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

cd %{sources}
# Sanity check, really often broken
extver=$(sed -n '/#define PHP_RPMINFO_VERSION/{s/.* "//;s/".*$//;p}' php_rpminfo.h)
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable '%{summary}' extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}
sed -e 's/INSTALL_ROOT/DESTDIR/' -i build/Makefile.global

cd ../NTS
%configure \
    --enable-rpminfo \
    --with-libdir=%{_lib} \
    --with-php-config=%{__phpconfig}

%make_build

%{__php} --no-php-ini \
    --define extension=modules/%{pecl_name}.so \
    --re %{pecl_name} >../%{sources}/REFLECTION

%if %{with_zts}
cd ../ZTS
%configure \
    --enable-rpminfo \
    --with-libdir=%{_lib} \
    --with-php-config=%{__ztsphpconfig}

%make_build
%endif


%install
%{?dtsenable}

%make_install -C NTS

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
%make_install -C ZTS

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//') REFLECTION
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
cd %{sources}
%if 0%{?fedora} < 37 && 0%{?rhel} < 10
# OLD mock install sqlite db, rpm expect db6 format
# NEW mock install in /usr/lib/sysimage/rpm instead of /var/lib/rpm
rm tests/007-rpmdbinfo.phpt
rm tests/008-rpmdbsearch.phpt
rm tests/013-rpmdbsearch-error.phpt
%endif

# Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}/%{php_extdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with tests}
# Upstream test suite  for NTS extension
TEST_PHP_ARGS="-n -d extension=%{buildroot}/%{php_extdir}/%{pecl_name}.so" \
%{__php} -n run-tests.php -q --show-diff %{?_smp_mflags}
%endif

%if %{with_zts}
# Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}/%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with tests}
# Upstream test suite  for ZTS extension
TEST_PHP_ARGS="-n -d extension=%{buildroot}/%{php_ztsextdir}/%{pecl_name}.so" \
%{__ztsphp} -n run-tests.php -q --show-diff %{?_smp_mflags}
%endif
%endif


%files
%license %{sources}/LICENSE
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Thu Dec 19 2024 Remi Collet <remi@remirepo.net> - 1.2.0-1
- update to 1.2.0
- re-license spec file to CECILL-2.1

* Tue Sep 24 2024 Remi Collet <remi@remirepo.net> - 1.1.1-2
- rebuild for 8.4.0RC1

* Tue Sep  3 2024 Remi Collet <remi@remirepo.net> - 1.1.1-1
- update to 1.1.1

* Fri Nov 10 2023 Remi Collet <remi@remirepo.net> - 1.1.0-1
- update to 1.1.0

* Fri Oct 13 2023 Remi Collet <remi@remirepo.net> - 1.0.1-1
- update to 1.0.1

* Thu Oct 12 2023 Remi Collet <remi@remirepo.net> - 1.0.0-1
- update to 1.0.0

* Tue Sep 26 2023 Remi Collet <remi@remirepo.net> - 0.7.0-1
- update to 0.7.0
- drop support for PHP 7

* Wed Aug 30 2023 Remi Collet <remi@remirepo.net> - 0.6.0-7
- rebuild for PHP 8.3.0RC1

* Tue Jun  6 2023 Remi Collet <remi@remirepo.net> - 0.6.0-6
- build out of sources tree

* Thu Sep  1 2022 Remi Collet <remi@remirepo.net> - 0.6.0-5
- rebuild for PHP 8.2.0RC1

* Thu Feb 10 2022 Remi Collet <remi@remirepo.net> - 0.6.0-4
- also ignore tests on F36 after database relocation

* Tue Sep 28 2021 Remi Collet <remi@remirepo.net> - 0.6.0-3
- add REFLECTION file to package documentation

* Wed Sep 01 2021 Remi Collet <remi@remirepo.net> - 0.6.0-2
- rebuild for 8.1.0RC1

* Fri Jun 18 2021 Remi Collet <remi@remirepo.net> - 0.6.0-1
- update to 0.6.0
- raise dependency on PHP 7.2

* Tue Jun  8 2021 Remi Collet <remi@remirepo.net> - 0.5.1-7
- fix test suite

* Wed Sep 30 2020 Remi Collet <remi@remirepo.net> - 0.5.1-6
- rebuild for PHP 8.0.0RC1

* Wed Sep 23 2020 Remi Collet <remi@remirepo.net> - 0.5.1-5
- update to 0.5.1

* Wed Sep  2 2020 Remi Collet <remi@remirepo.net> - 0.5.0-5
- rebuild for PHP 8.0.0beta3

* Tue Aug 18 2020 Remi Collet <remi@remirepo.net> - 0.5.0-4
- ignore 2 (expected) failed tests on F33

* Wed Aug  5 2020 Remi Collet <remi@remirepo.net> - 0.5.0-3
- rebuild for 8.0.0beta1

* Fri Apr 10 2020 Remi Collet <remi@remirepo.net> - 0.5.0-2
- add upstream patch for test suite and PHP 8

* Tue Apr  7 2020 Remi Collet <remi@remirepo.net> - 0.5.0-1
- update to 0.5.0

* Wed Mar 25 2020 Remi Collet <remi@remirepo.net> - 0.4.2-1
- update to 0.4.2

* Wed Mar 18 2020 Remi Collet <remi@remirepo.net> - 0.4.1-1
- update to 0.4.1

* Fri Mar 13 2020 Remi Collet <remi@remirepo.net> - 0.4.0-1
- update to 0.4.0 (stable)

* Thu Mar 12 2020 Remi Collet <remi@remirepo.net> - 0.3.1-1
- update to 0.3.1

* Thu Mar 12 2020 Remi Collet <remi@remirepo.net> - 0.3.0-1
- update to 0.3.0

* Wed Mar 11 2020 Remi Collet <remi@remirepo.net> - 0.2.3-1
- update to 0.2.3

* Wed Mar 11 2020 Remi Collet <remi@remirepo.net> - 0.2.2-1
- update to 0.2.2

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 0.2.1-5
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 0.2.1-4
- rebuild for 7.4.0beta1

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 0.2.1-3
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 0.2.1-2
- rebuild for 7.3.0alpha4 new ABI

* Mon Feb 12 2018 Remi Collet <remi@remirepo.net> - 0.2.1-1
- update to 0.2.1 (beta)

* Thu Feb  8 2018 Remi Collet <remi@remirepo.net> - 0.2.0-1
- update to 0.2.0 (beta)

* Thu Feb  8 2018 Remi Collet <remi@remirepo.net> - 0.1.2-1
- update to 0.1.2

* Fri Jan 26 2018 Remi Collet <remi@remirepo.net> - 0.1.1-1
- initial package, version 0.1.1 (alpha)
